==> mktcenter-service-1.5.2-vg-20220726.103050-22-sources.jar: com/bizvane/mktcenterservice/models/bo/ActivityBO.java <==
package com.bizvane.mktcenterservice.models.bo;

import com.bizvane.couponfacade.models.vo.CouponDetailResponseVO;
import com.bizvane.couponfacade.models.vo.CouponEntityAndDefinitionVO;
import com.bizvane.members.facade.models.MbrGroupModel;
import com.bizvane.mktcenterservice.models.po.MktCouponPO;
import com.bizvane.mktcenterservice.models.po.MktMessagePO;
import com.bizvane.mktcenterservice.models.vo.ActivityVO;
import com.bizvane.mktcenterservice.models.vo.MessageVO;
import com.bizvane.serviceCard.models.po.giftCard.GiftCardDefPO;

import java.util.List;

/**
 * @author chen.li
 * @date on 2018/7/14 10:20
 * @description 活动业务大对象
 * @Copyright (c) 2018 上海商帆信息科技有限公司-版权所有
 */
public class ActivityBO {

    /**
     * 活动对象
     */
    private ActivityVO activityVO;

    /**
     * 券对象
     */
    private List<MktCouponPO> couponCodeList;

    /**
     * 消息对象
     */
    private List<MktMessagePO> messageVOList;

    private MbrGroupModel mbrGroupModel;

    /**
     * 调用券接口的券对象
     */
    private List<CouponDetailResponseVO> couponEntityAndDefinitionVOList;

    private  List<GiftCardDefPO> giftCardDefPOList;

    public List<CouponDetailResponseVO> getCouponEntityAndDefinitionVOList() {
        return couponEntityAndDefinitionVOList;
    }

    public void setCouponEntityAndDefinitionVOList(List<CouponDetailResponseVO> couponEntityAndDefinitionVOList) {
        this.couponEntityAndDefinitionVOList = couponEntityAndDefinitionVOList;
    }

    public List<MktMessagePO> getMessageVOList() {
        return messageVOList;
    }

    public void setMessageVOList(List<MktMessagePO> messageVOList) {
        this.messageVOList = messageVOList;
    }

    public List<MktCouponPO> getCouponCodeList() {
        return couponCodeList;
    }

    public void setCouponCodeList(List<MktCouponPO> couponCodeList) {
        this.couponCodeList = couponCodeList;
    }

    public ActivityVO getActivityVO() {
        return activityVO;
    }

    public void setActivityVO(ActivityVO activityVO) {
        this.activityVO = activityVO;
    }

    public MbrGroupModel getMbrGroupModel() {
        return mbrGroupModel;
    }

    public void setMbrGroupModel(MbrGroupModel mbrGroupModel) {
        this.mbrGroupModel = mbrGroupModel;
    }

    public List<GiftCardDefPO> getGiftCardDefPOList() {
        return giftCardDefPOList;
    }

    public void setGiftCardDefPOList(List<GiftCardDefPO> giftCardDefPOList) {
        this.giftCardDefPOList = giftCardDefPOList;
    }
}

==> mktcenter-service-1.5.7-vg-20231123.095934-4-sources.jar: com/bizvane/mktcenterservice/models/bo/ActivityBO.java <==
package com.bizvane.mktcenterservice.models.bo;

import com.bizvane.couponfacade.models.vo.CouponDetailResponseVO;
import com.bizvane.couponfacade.models.vo.CouponEntityAndDefinitionVO;
import com.bizvane.members.facade.models.MbrGroupModel;
import com.bizvane.messagebase.model.po.MsgWxTempPO;
import com.bizvane.mktcenterservice.models.po.MktActivityPO;
import com.bizvane.mktcenterservice.models.po.MktCouponPO;
import com.bizvane.mktcenterservice.models.po.MktMessagePO;
import com.bizvane.mktcenterservice.models.vo.ActivityVO;
import com.bizvane.mktcenterservice.models.vo.MessageVO;
import com.bizvane.serviceCard.models.po.giftCard.GiftCardDefPO;

import java.util.List;

/**
 * @author chen.li
 * @date on 2018/7/14 10:20
 * @description 活动业务大对象
 * @Copyright (c) 2018 上海商帆信息科技有限公司-版权所有
 */
public class ActivityBO {

    /**
     * 活动对象
     */
    private ActivityVO activityVO;

    /**
     * 券对象
     */
    private List<MktCouponPO> couponCodeList;

    /**
     * 消息对象
     */
    private List<MktMessagePO> messageVOList;

    private MbrGroupModel mbrGroupModel;

    /**
     * 调用券接口的券对象
     */
    private List<CouponDetailResponseVO> couponEntityAndDefinitionVOList;

    private  List<GiftCardDefPO> giftCardDefPOList;

    private MsgWxTempPO msgWxTempPO;

    private MktActivityPO gameActivityPO;

    public MktActivityPO getGameActivityPO() {
        return gameActivityPO;
    }

    public void setGameActivityPO(MktActivityPO gameActivityPO) {
        this.gameActivityPO = gameActivityPO;
    }

    public List<CouponDetailResponseVO> getCouponEntityAndDefinitionVOList() {
        return couponEntityAndDefinitionVOList;
    }

    public void setCouponEntityAndDefinitionVOList(List<CouponDetailResponseVO> couponEntityAndDefinitionVOList) {
        this.couponEntityAndDefinitionVOList = couponEntityAndDefinitionVOList;
    }

    public List<MktMessagePO> getMessageVOList() {
        return messageVOList;
    }

    public void setMessageVOList(List<MktMessagePO> messageVOList) {
        this.messageVOList = messageVOList;
    }

    public List<MktCouponPO> getCouponCodeList() {
        return couponCodeList;
    }

    public void setCouponCodeList(List<MktCouponPO> couponCodeList) {
        this.couponCodeList = couponCodeList;
    }

    public ActivityVO getActivityVO() {
        return activityVO;
    }

    public void setActivityVO(ActivityVO activityVO) {
        this.activityVO = activityVO;
    }

    public MbrGroupModel getMbrGroupModel() {
        return mbrGroupModel;
    }

    public void setMbrGroupModel(MbrGroupModel mbrGroupModel) {
        this.mbrGroupModel = mbrGroupModel;
    }

    public List<GiftCardDefPO> getGiftCardDefPOList() {
        return giftCardDefPOList;
    }

    public void setGiftCardDefPOList(List<GiftCardDefPO> giftCardDefPOList) {
        this.giftCardDefPOList = giftCardDefPOList;
    }

    public MsgWxTempPO getMsgWxTempPO() {
        return msgWxTempPO;
    }

    public void setMsgWxTempPO(MsgWxTempPO msgWxTempPO) {
        this.msgWxTempPO = msgWxTempPO;
    }
}
